@@ -36,7 +36,7 @@ sub need_downloader() {
 	-e "/bin/$_" and $found = 1;
     }
     if (!$found) {
-	warn "SKIPing because we're missing a downloader. We need one of wget∕curl/prozilla/aria2c";
+	warn "SKIPing because we're missing a downloader. We need one of wget/curl/prozilla/aria2c";
 	#plan skip_all => "*BSD fails those";
 	exit 0;
     }
